@@ -18,10 +18,10 @@
 #'@return \item{cvm}{Cramer-von-Mises statistic for goodness-of-fit}
 #'@return \item{W}{regime probabilities for the conditional distribution given the past Kendall's tau}
 #'
+#'
 #@references https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3271474
 #'
-#'
-#'@examples Q <- matrix(c(0.8, 0.2, 0.3, 0.7),2,2) ; kendallTau <- c(0.3 ,0.7) ;
+#'@examples Q <- matrix(c(0.8, 0.3, 0.2, 0.7),2,2) ; kendallTau <- c(0.3 ,0.7) ;
 #'data <- SimHMMCop(Q, 'clayton', kendallTau, 10)$SimData;
 #'estimations <- EstHMMCop(data,2,'clayton',10000,0.0001)
 #'
@@ -232,19 +232,22 @@ EMStep <- function(y,theta,Q,family){
   Qnew = Q
 
   if (r >= 2){
+    #for(j in 1:r){
+      #Lambda2_1 = matrix(Lambda[j,1,], n, 1)
+      #Lambda2_2 = matrix(Lambda[j,2,], n, 1)
+      #Lambda2 = matrix(c(Lambda2_1,Lambda2_2),n,2)
+      #sv = apply(Lambda2, 2, sum)
+      ##   sv = rowSums(Lambda2, dims=2)
+      ##  sv = rowSums(Lambda[j,,])
+      #ssv = sum(sv)
+      #Qnew[j,] = sv / ssv
+    #}
     for(j in 1:r){
-      Lambda2_1 = matrix(Lambda[j,1,], n, 1)
-      Lambda2_2 = matrix(Lambda[j,2,], n, 1)
-      Lambda2 = matrix(c(Lambda2_1,Lambda2_2),n,2)
-      sv = apply(Lambda2, 2, sum)
-      #   sv = rowSums(Lambda2, dims=2)
-      #   sv = rowSums(Lambda[j,,])
+      sv = rowSums(Lambda[j,,], dims=1)
       ssv = sum(sv)
       Qnew[j,] = sv / ssv
     }
-  } #else if (r < 2){
-    #Qnew = 1;
-  #}
+  }
 
 
 
